==================================================
PipeML: Pipeline tools for machine learning models
==================================================

.. image:: http://img.shields.io/pypi/v/pipeml.svg?style=flat
   :target: https://pypi.python.org/pypi/pipeml
   :alt: Version_status
.. image:: http://img.shields.io/badge/docs-latest-brightgreen.svg?style=flat
   :target: https://pipeml.readthedocs.io/en/latest/
   :alt: Documentation
.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
   :target: https://github.com/yoelcortes/pipeml/blob/master/LICENSE.txt
   :alt: license

.. contents::

What is PipeML?
---------------

PipeML constitutes a set of tools to work with machine learning models. PipeML does not implement machine learning models nor does it serve to build model. It is simply used to interface more easily with machine learning models

Installation
------------

Get the latest version of PipeML from `PyPI <https://pypi.python.org/pypi/pipeml/>`__. If you have an installation of Python with pip, simple install it with:

    $ pip install pipeml

To get the git version, run:

    $ git clone git://github.com/yoelcortes/pipeml

Documentation
-------------

TODO

Bug reports
-----------

To report bugs, please use the PipeML's Bug Tracker at:

    https://github.com/yoelcortes/pipeml


License information
-------------------

See ``LICENSE.txt`` for information on the terms & conditions for usage
of this software, and a DISCLAIMER OF ALL WARRANTIES.

Although not required by the PipeML license, if it is convenient for you,
please cite PipeML if used in your work. Please also consider contributing
any changes you make back, and benefit the community.



